<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
<context>
    <name>App.About</name>
    <message>
        <source>System Monitor</source>
        <translation>Нагляд за системою</translation>
    </message>
    <message>
        <source>System Monitor is a tool to monitor realtime system load, view and control processes and services running on your system.</source>
        <translation>Монітор системи — інструмент для спостереження за навантаженням на систему у режимі реального часу, перегляду списку процесів та керування процесами та службами, які запущено у вашій системі.</translation>
    </message>
</context>
<context>
    <name>BaseDetailViewWidget</name>
    <message>
        <source>Hide details</source>
        <translation>Приховати подробиці</translation>
    </message>
    <message>
        <source>Overall utilization</source>
        <translation>Загальне використання</translation>
    </message>
    <message>
        <source>Individual utilization</source>
        <translation>Окреме використання</translation>
    </message>
</context>
<context>
    <name>BlockDevItemWidget</name>
    <message>
        <source>Read</source>
        <translation>Читання</translation>
    </message>
    <message>
        <source>Write</source>
        <translation>Запис</translation>
    </message>
</context>
<context>
    <name>CPUDetailGrapTableItem</name>
    <message>
        <source>60 seconds</source>
        <translation>60 секунд</translation>
    </message>
</context>
<context>
    <name>CPUInfoModel</name>
    <message>
        <source>%1 days %2 hours %3 minutes</source>
        <translation>%1 днів %2 годин %3 хвилин</translation>
    </message>
</context>
<context>
    <name>CPUSummaryTableModel</name>
    <message>
        <source>Utilization</source>
        <translation>Вжиток</translation>
    </message>
    <message>
        <source>Current frequency</source>
        <translation>Поточна частота</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Частота</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Виробник</translation>
    </message>
    <message>
        <source>Sockets</source>
        <translation>Сокети</translation>
    </message>
    <message>
        <source>Logical processors</source>
        <translation>Логічні процесори</translation>
    </message>
    <message>
        <source>Virtualization</source>
        <translation>Віртуалізація</translation>
    </message>
    <message>
        <source>L1i cache</source>
        <translation>Кеш L1i</translation>
    </message>
    <message>
        <source>L1d cache</source>
        <translation>Кеш L1d</translation>
    </message>
    <message>
        <source>L2 cache</source>
        <translation>Кеш L2</translation>
    </message>
    <message>
        <source>L3 cache</source>
        <translation>Кеш L3</translation>
    </message>
    <message>
        <source>Load average</source>
        <translation>Середнє навантаження</translation>
    </message>
    <message>
        <source>File descriptors</source>
        <translation>Дескриптори файлів</translation>
    </message>
    <message>
        <source>Processes</source>
        <translation>Процеси</translation>
    </message>
    <message>
        <source>Threads</source>
        <translation>Потоки обробки</translation>
    </message>
    <message>
        <source>Host name</source>
        <translation>Назва вузла</translation>
    </message>
    <message>
        <source>OS type</source>
        <translation>Тип ОС</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Версія</translation>
    </message>
    <message>
        <source>Up time</source>
        <translation>Час роботи</translation>
    </message>
</context>
<context>
    <name>ChartViewWidget</name>
    <message>
        <source>60 seconds</source>
        <translation>60 секунд</translation>
    </message>
</context>
<context>
    <name>Common.Search</name>
    <message>
        <source>No search results</source>
        <translation>Нічого не знайдено</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>Подробиці</translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>Подробиці</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Active.State</name>
    <message>
        <source>active</source>
        <translation>активний</translation>
    </message>
    <message>
        <source>reloading</source>
        <translation>перезавантаження</translation>
    </message>
    <message>
        <source>inactive</source>
        <translation>неактивний</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>невдача</translation>
    </message>
    <message>
        <source>activating</source>
        <translation>активація</translation>
    </message>
    <message>
        <source>deactivating</source>
        <translation>деактивація</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Load.State</name>
    <message>
        <source>stub</source>
        <translation>заглушка</translation>
    </message>
    <message>
        <source>not-found</source>
        <translation>не-знайдено</translation>
    </message>
    <message>
        <source>bad-setting</source>
        <translation>помилковий-параметр</translation>
    </message>
    <message>
        <source>error</source>
        <translation>помилка</translation>
    </message>
    <message>
        <source>merged</source>
        <translation>об’єднано</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>замасковано</translation>
    </message>
    <message>
        <source>loaded</source>
        <translation>завантажено</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Startup.Mode</name>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Авто</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ручний </translation>
    </message>
</context>
<context>
    <name>DBus.Unit.State</name>
    <message>
        <source>enabled</source>
        <translation>увімкнено</translation>
    </message>
    <message>
        <source>disabled</source>
        <translation>вимкнено</translation>
    </message>
    <message>
        <source>static</source>
        <translation>статика</translation>
    </message>
    <message>
        <source>transient</source>
        <translation>проміжний</translation>
    </message>
    <message>
        <source>indirect</source>
        <translation>опосередкований</translation>
    </message>
    <message>
        <source>enabled-runtime</source>
        <translation>увімкнено-робота</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>замасковано</translation>
    </message>
    <message>
        <source>generated</source>
        <translation>створено</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Sub.State</name>
    <message>
        <source>dead</source>
        <translation>мрець</translation>
    </message>
    <message>
        <source>start-pre</source>
        <translation>приг-запуск</translation>
    </message>
    <message>
        <source>start</source>
        <translation>запуск</translation>
    </message>
    <message>
        <source>start-post</source>
        <translation>після-запуску</translation>
    </message>
    <message>
        <source>running</source>
        <translation>виконується</translation>
    </message>
    <message>
        <source>exited</source>
        <translation>вийшов</translation>
    </message>
    <message>
        <source>reload</source>
        <translation>перезавантажити</translation>
    </message>
    <message>
        <source>stop</source>
        <translation>зупинити</translation>
    </message>
    <message>
        <source>stop-watchdog</source>
        <translation>зупин-спостереження</translation>
    </message>
    <message>
        <source>stop-sigterm</source>
        <translation>зупинка-сиг-перервати</translation>
    </message>
    <message>
        <source>stop-sigkill</source>
        <translation>зупинка-сиг-вбити</translation>
    </message>
    <message>
        <source>stop-post</source>
        <translation>пост-зупинка</translation>
    </message>
    <message>
        <source>final-sigterm</source>
        <translation>ост-сигн-переривання</translation>
    </message>
    <message>
        <source>final-sigkill</source>
        <translation>ост-сиг-вбивство</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>помилка</translation>
    </message>
    <message>
        <source>auto-restart</source>
        <translation>авто-перезапуск</translation>
    </message>
</context>
<context>
    <name>DeailTableModel</name>
    <message>
        <source>Used</source>
        <translation>Використано</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Доступно</translation>
    </message>
    <message>
        <source>Shared</source>
        <translation>Спільно</translation>
    </message>
    <message>
        <source>Cached</source>
        <translation>Кешовано</translation>
    </message>
    <message>
        <source>Buffers</source>
        <translation>Буфери</translation>
    </message>
    <message>
        <source>Cached swap</source>
        <translation>Кешований резерв</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Активний</translation>
    </message>
    <message>
        <source>Inactive</source>
        <translation>Неактивний</translation>
    </message>
    <message>
        <source>Dirty</source>
        <translation>Змінено</translation>
    </message>
    <message>
        <source>Mapped</source>
        <translation>Пов&apos;язано</translation>
    </message>
    <message>
        <source>Total swap</source>
        <translation>Загальний резерв</translation>
    </message>
    <message>
        <source>Free swap</source>
        <translation>Вільний резерв</translation>
    </message>
    <message>
        <source>Slab</source>
        <translation>Частина</translation>
    </message>
</context>
<context>
    <name>DeailTableModelBlock</name>
    <message>
        <source>Model</source>
        <translation>Модель</translation>
    </message>
    <message>
        <source>Read speed</source>
        <translation>Швидкість читання</translation>
    </message>
    <message>
        <source>Write speed</source>
        <translation>Швидкість запису</translation>
    </message>
    <message>
        <source>Capacity</source>
        <translation>Місткість</translation>
    </message>
    <message>
        <source>Sectors read</source>
        <translation>Секторів прочитано</translation>
    </message>
    <message>
        <source>Reads/s</source>
        <translation>Читань/с</translation>
    </message>
    <message>
        <source>Sectors read/s</source>
        <translation>Прочитаних секторів/с</translation>
    </message>
    <message>
        <source>Reads merged/s</source>
        <translation>Об&apos;єднаних читань/с</translation>
    </message>
    <message>
        <source>Sectors written</source>
        <translation>Записано секторів</translation>
    </message>
    <message>
        <source>Writes completed </source>
        <translation>Завершено записів</translation>
    </message>
    <message>
        <source>Writes merged</source>
        <translation>Об&apos;єднано записів</translation>
    </message>
    <message>
        <source>Writes/s</source>
        <translation>Записів/с</translation>
    </message>
    <message>
        <source>Sectors written/s</source>
        <translation>Записано секторів/с</translation>
    </message>
    <message>
        <source>Writes merged/s</source>
        <translation>Об&apos;єднано записів/с</translation>
    </message>
</context>
<context>
    <name>Error.Dialog</name>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation>Гаразд</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <source>System</source>
        <translation>Система</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Показати скорочення</translation>
    </message>
</context>
<context>
    <name>Kill.Process.Dialog</name>
    <message>
        <source>Ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Завершення роботи цього процесу може призвести до втрати даних. Ви справді хочете виконати цю дію?</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>Завершити процес</translation>
    </message>
    <message>
        <source>Force ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Примусове завершення роботи цього процесу може призвести до втрати даних. Ви справді хочете виконати цю дію?</translation>
    </message>
    <message>
        <source>Force ending this application may cause data loss.
Are you sure you want to continue?</source>
        <translation>Примусове припинення роботи цієї програми може призвести до втрати даних.
Ви впевнені, що хочете продовжити?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Force End</source>
        <comment>button</comment>
        <translation>Примусове завершення</translation>
    </message>
    <message>
        <source>End</source>
        <comment>button</comment>
        <translation>Завершити</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Settings</source>
        <translation>Параметри</translation>
    </message>
</context>
<context>
    <name>MemStatViewWidget</name>
    <message>
        <source>Size</source>
        <translation>Розмір</translation>
    </message>
</context>
<context>
    <name>NetInfoDetailItemDelegate</name>
    <message>
        <source>IP address:</source>
        <translation>Адреса IP:</translation>
    </message>
    <message>
        <source>Netmask:</source>
        <translation>Маска мережі:</translation>
    </message>
    <message>
        <source>Broadcast:</source>
        <translation>Трансляція:</translation>
    </message>
    <message>
        <source>Prefixlen:</source>
        <translation>Довж. префікса:</translation>
    </message>
    <message>
        <source>Scope:</source>
        <translation>Область:</translation>
    </message>
</context>
<context>
    <name>NetInfoModel</name>
    <message>
        <source>Connection type</source>
        <translation>Тип з&apos;єднання</translation>
    </message>
    <message>
        <source>ESSID</source>
        <translation>ESSID</translation>
    </message>
    <message>
        <source>Link quality</source>
        <translation>Якість зв&apos;язку</translation>
    </message>
    <message>
        <source>Signal strength</source>
        <translation>Потужність сигналу</translation>
    </message>
    <message>
        <source>Noise level</source>
        <translation>Рівень шуму</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>Bandwidth</source>
        <translation>Ширина каналу</translation>
    </message>
    <message>
        <source>RX packets</source>
        <translation>Отримано пакетів</translation>
    </message>
    <message>
        <source>RX bytes</source>
        <translation>Отримано байтів</translation>
    </message>
    <message>
        <source>RX errors</source>
        <translation>Помилки отримання</translation>
    </message>
    <message>
        <source>RX dropped</source>
        <translation>Відкинуто отриманих</translation>
    </message>
    <message>
        <source>RX overruns</source>
        <translation>Переповнень отримання</translation>
    </message>
    <message>
        <source>RX frame</source>
        <translation>Кадр отримання</translation>
    </message>
    <message>
        <source>TX packets</source>
        <translation>Переданих пакетів</translation>
    </message>
    <message>
        <source>TX bytes</source>
        <translation>Переданих байтів</translation>
    </message>
    <message>
        <source>TX errors</source>
        <translation>Помилки передавання</translation>
    </message>
    <message>
        <source>TX overruns</source>
        <translation>Переповнень передавання</translation>
    </message>
    <message>
        <source>TX carrier</source>
        <translation>Носій передавання</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>TX dropped</source>
        <translation>Відкинуто переданих</translation>
    </message>
</context>
<context>
    <name>Process.Attributes.Dialog</name>
    <message>
        <source>Command line</source>
        <translation>Командний рядок</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>Час початку</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Назва</translation>
    </message>
</context>
<context>
    <name>Process.Choose.Window.Dialog</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>Натисніть пункт програми, роботу якої ви хочете завершити</translation>
    </message>
</context>
<context>
    <name>Process.Graph.Title</name>
    <message>
        <source>Memory</source>
        <translation>Пам&apos;ять</translation>
    </message>
    <message>
        <source>Receive</source>
        <translation>Отримання</translation>
    </message>
</context>
<context>
    <name>Process.Graph.View</name>
    <message>
        <source>CPU</source>
        <translation>Процесор</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Читання з диска</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Запис на диск</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Пам&apos;ять</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Резервна пам&apos;ять</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Не ввімкнено</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Отримання</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Надсилання</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Мережа</translation>
    </message>
    <message>
        <source>Total Received</source>
        <translation>Загалом отримано</translation>
    </message>
    <message>
        <source>Total Sent</source>
        <translation>Загалом надіслано</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Надіслання</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Диски</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <source>Very high</source>
        <translation>Дуже висока</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Висока</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Звичайна</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Низька</translation>
    </message>
    <message>
        <source>Very low</source>
        <translation>Дуже низька</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Нетипова</translation>
    </message>
    <message>
        <source>Invalid</source>
        <translation>Некоректна</translation>
    </message>
    <message>
        <source>PID: %1, Error: [%2] %3</source>
        <translation>PID: %1, помилка: [%2] %3</translation>
    </message>
    <message>
        <source>Failed to change process priority</source>
        <translation>Не вдалося змінити рівень пріоритетності процесу</translation>
    </message>
</context>
<context>
    <name>Process.Show.Mode</name>
    <message>
        <source>Applications</source>
        <translation>Програми</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>Мої процеси</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>Всі процеси</translation>
    </message>
</context>
<context>
    <name>Process.Loading</name>
    <message>
        <source>Loading</source>
        <translation>Завантаження</translation>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <source>Failed to pause process</source>
        <translation>Не вдалося призупинити роботу процесу</translation>
    </message>
    <message>
        <source>Failed to resume process</source>
        <translation>Не вдалося відновити роботу процесу</translation>
    </message>
    <message>
        <source>Failed to kill process</source>
        <translation>Не вдалося примусово завершити роботу процесу</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Невідома помилка</translation>
    </message>
    <message>
        <source>Failed in sending signal to process</source>
        <translation>Не вдалося надіслати процесу сигнал</translation>
    </message>
    <message>
        <source>Failed to end process</source>
        <translation>Не вдалося завершити процес</translation>
    </message>
</context>
<context>
    <name>Process.Summary</name>
    <message>
        <source>(%1 applications and %2 processes are running)</source>
        <translation>(запущено %1 програм і %2 процесів)</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <source>No response</source>
        <translation>Немає відповіді</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Призупинити</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Лоток</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <source>View command location</source>
        <translation>Переглянути розташування програми</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Властивості</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>Завершити процес</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>Відновити роботу процесу</translation>
    </message>
    <message>
        <source>Kill process</source>
        <translation>Вбити процес</translation>
    </message>
    <message>
        <source>Change priority</source>
        <translation>Змінити пріоритетність</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>Призупинити процес</translation>
    </message>
</context>
<context>
    <name>Process.Table.Custom.Priority.Dialog</name>
    <message>
        <source>Custom Priority</source>
        <translation>Нетипова пріоритетність</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Change</source>
        <comment>button</comment>
        <translation>Змінити</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Назва</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>Процесор</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Пам&apos;ять</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Запис на диск</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Читання з диска</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Отримання</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Надсилання</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Користувач</translation>
    </message>
    <message>
        <source>Nice</source>
        <translation>Ніцца</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Пріоритетність</translation>
    </message>
    <message>
        <source>Shared memory</source>
        <translation>Спільна пам&apos;ять</translation>
    </message>
    <message>
        <source>Virtual memory</source>
        <translation>Віртуальна пам&apos;ять</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Not support</source>
        <translation>Немає підтримки</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Параметри</translation>
    </message>
    <message>
        <source>System Protection</source>
        <translation>Захист системи</translation>
    </message>
    <message>
        <source>Show warnings when the usage exceeds the thresholds</source>
        <translation>Показувати попередження, якщо використання перевищує порогове значення</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Сповіщення</translation>
    </message>
    <message>
        <source>CPU warning threshold (%)</source>
        <translation>Поріг попередження для процесора (%)</translation>
    </message>
    <message>
        <source>Memory warning threshold (%)</source>
        <translation>Поріг попередження для пам&apos;яті (%)</translation>
    </message>
    <message>
        <source>Warning interval (min)</source>
        <translation>Інтервал попередження (хв.)</translation>
    </message>
</context>
<context>
    <name>Service.Action.Set.Startup.Mode</name>
    <message>
        <source>Failed to set service startup type</source>
        <translation>Не вдалося встановити тип запуску служби</translation>
    </message>
    <message>
        <source>Error: Failed to set service startup type due to the crashed sub process.</source>
        <translation>Помилка: Не вдалося встановити тип запуску служби через збій підпроцесу.</translation>
    </message>
</context>
<context>
    <name>Service.Instance.Name.Dialog</name>
    <message>
        <source>Service instance name</source>
        <translation>Назва екземпляра служби</translation>
    </message>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation>Гаразд</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Скасувати</translation>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <source>Refresh</source>
        <translation>Оновити</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Запустити</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Зупинити</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation>Перезапустити</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Авто</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ручний </translation>
    </message>
    <message>
        <source>Startup type</source>
        <translation>Тип запуску</translation>
    </message>
</context>
<context>
    <name>Service.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Назва</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Завантажити</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Активний</translation>
    </message>
    <message>
        <source>Sub</source>
        <translation>Підпрограма</translation>
    </message>
    <message>
        <source>State</source>
        <translation>Стан</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Опис</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Startup Type</source>
        <translation>Тип запуску</translation>
    </message>
</context>
<context>
    <name>SystemProtectionSetting</name>
    <message>
        <source>Settings</source>
        <translation>Параметри</translation>
    </message>
    <message>
        <source>(Modifiable)</source>
        <translation>(Можна змінити)</translation>
    </message>
    <message>
        <source>Range: %1-%2</source>
        <translation>Діапазон: %1-%2</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <source>Force end application</source>
        <translation>Примусове завершення програми</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Розгорнути</translation>
    </message>
    <message>
        <source>Compact</source>
        <translation>Компактний</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Переглянути</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <source>Search</source>
        <translation>Пошук</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <source>Processes</source>
        <translation>Процеси</translation>
    </message>
    <message>
        <source>Services</source>
        <translation>Служби</translation>
    </message>
</context>
</TS>
